﻿using Cop.Borovkov.Var3.Models;
using PIHelperSh.PdfCreator;
using PIHelperSh.PdfCreator.Enums;
using PIHelperSh.PdfCreator.Models.PieChartModel;
using System.ComponentModel;
using static System.Runtime.InteropServices.Marshalling.IIUnknownCacheStrategy;

namespace Cop.Borovkov.Var3.Components
{
    public partial class CustomPdfHistogram : Component
    {
        public CustomPdfHistogram()
        {
            InitializeComponent();
        }

        public CustomPdfHistogram(IContainer container)
        {
            container.Add(this);

            InitializeComponent();
        }

        /// <summary>
        /// Сохранить гистограмму в пдф
        /// </summary>
        /// <param name="histogramInfo"></param>
        public void SaveToPdf(PdfHistigramInfo histogramInfo)
        {
            if (string.IsNullOrEmpty(histogramInfo.FilePath))
                throw new ArgumentException("Путь к файлу не должен быть пустым.");
            if (string.IsNullOrEmpty(histogramInfo.DocumentTitle))
                throw new ArgumentException("Название документа не должно быть пустым.");
            if (string.IsNullOrEmpty(histogramInfo.HistogramTitle))
                throw new ArgumentException("Заголовок диаграммы не должен быть пустым.");
            if (histogramInfo.Values == null || histogramInfo.Values.Count() == 0)
                throw new ArgumentException("Набор данных не должен быть пустым.");

            foreach (var data in histogramInfo.Values)
            {
                if (string.IsNullOrEmpty(data.Name) || data.Points == null || data.Points.Count() == 0)
                    throw new ArgumentException($"Набор данных для серии '{data.Name}' некорректен.");
            }

            PdfCreator creator = new PdfCreator();

            creator.AddParagraph(new()
            {
                Style = PdfStyleType.Title,
                Text = histogramInfo.DocumentTitle,
                MarginAfter = PdfMargin.Smal,
            });

            creator.AddHistogram(new()
            {
                ChartName = histogramInfo.HistogramTitle,
                LegendPosition = histogramInfo.LegendPosition,
                DataSet = histogramInfo.Values.Select(l => new PdfHistogramData()
                {
                    DisplayName = l.Name,
                    Value = l.Points.Select(p => (p.Name, p.Value))
                }).ToList() 
            });

            creator.SavePdf(histogramInfo.FilePath);
        }
    }
}
