﻿using Cop.Borovkov.Var3.Models;
using PIHelperSh.PdfCreator.Models.TableModels;
using PIHelperSh.PdfCreator;
using System.ComponentModel;
using PIHelperSh.PdfCreator.Enums;
using PIHelperSh.PdfCreator.Interfaces;

namespace Cop.Borovkov.Var3.Components
{
    /// <summary>
    /// Компонент создающий таблицу и группирует элементы по 1 столбцу
    /// </summary>
    public partial class CustomPdfTableWithGrouping : Component
    {
        /// <summary>
        /// </summary>
        public CustomPdfTableWithGrouping()
        {
            InitializeComponent();
        }

        /// <summary>
        /// </summary>
        /// <param name="container"></param>
        public CustomPdfTableWithGrouping(IContainer container)
        {
            container.Add(this);
            InitializeComponent();
        }

        /// <summary>
        /// Сохранить набор таблиц в пдф
        /// </summary>
        /// <param name="fileName"></param>
        /// <param name="title"></param>
        /// <param name="tables"></param>
        public void SaveToPdf<TType>(PdfTableWithGroupingInfo<TType> tableInfo) where TType : class
        {
            if (!tableInfo.Columns.Any() || !tableInfo.Rows.Any())
            {
                return;
            }

            PdfCreator creator = new PdfCreator();

            creator.AddParagraph(new()
            {
                Style = PdfStyleType.Title,
                Text = tableInfo.Title,
                MarginAfter = PdfMargin.Smal,
            });

            creator.AddTable(new PdfTable<TType>()
            {
                Header = tableInfo.Columns.Select(c => new PdfTableColumn()
                {
                    Title = c.Header,
                    Size = c.Width,
                    PropertyName = c.PropertyName,
                } as IPdfColumnItem).ToList(),

                Records = tableInfo.Rows
                    .OrderBy(r => typeof(TType)
                        .GetProperty(tableInfo.Columns.First().PropertyName)!.GetValue(r.Value))
                    .Select(r => (r.Value, r.Height))
                    .ToList(),
                HeaderHeaight = tableInfo.HeaderHeight,
            });

            creator.SavePdf(tableInfo.FilePath);
        }
    }
}
